body {
    font-family: sans-serif;
    font-size: 100%;
    background-color: #444;
    color: #000;
    margin: 1em;
}

h1.title {
    color: #2C471A;
    font-size: 150%;
    text-align: center;
}

h1 {
    color: #2C471A;
    font-size: 120%;
}

h2 {
    color: #2C471A;
    font-size: 100%;
}

div.document {
    background-color: #fff;
    padding: 1em;
}

div.rating {
    text-align: center;
    font-size: 80%;
    float: left;
    padding: 0.5em;
}

div.note {
    background-color: #eaf2f9;
	margin: 1em;
    border: 1px solid #3d7aa5;
    border-left: none;
    border-right: none;
    font-size: .8em;
}

table.questionaire {
    padding: 0px;
}

tr.oddrow {
    background-color: #ddd;
}

table.questionaire td {
    padding: 0px;
    margin: 0px;
}

td.response {
    text-align: left;
    white-space: nowrap;
    background-color: #eeffcc;
}

tr.oddrow td.response {
    background-color: #ccd9af;
}

td.task {
    text-align: left;
}

th p,
td p {
    padding: 0.2em;
    margin: 0px;
}

a {
    color: #820430;
    text-decoration: none;
}

a:hover {
    text-decoration: underline;
}


